Module statistical

Module statistical 

Statistical regression detection algorithms.

Provides:

  • StatRegressionDetector — z-score + relative-change detector with Welford online mean/variance estimation.
  • CusumDetector — CUSUM sequential change-point detection algorithm.

These supplement the performance-baseline detector in detector.rs with algorithms operating directly on a streaming sequence of scalar metric values rather than on full profiling reports.

Structs

CusumAlert
Alert emitted by CusumDetector when a change point is detected.
CusumDetector
CUSUM (Cumulative Sum) sequential change-point detector.
StatBaselineStats
Statistical summary of a reference sample set.
StatRegressionConfig
Configuration for StatRegressionDetector.
StatRegressionDetector
Statistical regression detector for a single scalar training metric.
StatRegressionEvent
A single detected regression event.

Enums

ChangeDirection
The direction of a CUSUM change-point alert.
StatRegressionDirection
Indicates the direction that is considered “bad” for a metric.
StatRegressionSeverity
Severity class for a detected regression event.